@@ -100,8 +100,8 @@ static ErlDrvData setuid_start(ErlDrvPort port, char *buf)
     }
     // In any case return error(?) for non void function
     return (ErlDrvData) -1;
-    
-        
+
+
 }
 
 
@@ -121,16 +121,29 @@ static void setuid_stop(ErlDrvData drv_data)
 
 DRIVER_INIT(setuid_drv)
 {
-    setuid_driver_entry.init         = NULL;   /* Not used */
-    setuid_driver_entry.start        = setuid_start;
-    setuid_driver_entry.stop         = setuid_stop;
-    setuid_driver_entry.output       = NULL;
-    setuid_driver_entry.ready_input  = NULL;
-    setuid_driver_entry.ready_output = NULL;
-    setuid_driver_entry.driver_name  = "setuid_drv";
-    setuid_driver_entry.finish       = NULL;
-    setuid_driver_entry.control      = NULL;
-    setuid_driver_entry.outputv      = NULL;
+    setuid_driver_entry.init            = NULL;   /* Not used */
+    setuid_driver_entry.start           = setuid_start;
+    setuid_driver_entry.stop            = setuid_stop;
+    setuid_driver_entry.output          = NULL;
+    setuid_driver_entry.ready_input     = NULL;
+    setuid_driver_entry.ready_output    = NULL;
+    setuid_driver_entry.driver_name     = "setuid_drv";
+    setuid_driver_entry.finish          = NULL;
+    setuid_driver_entry.handle          = NULL;
+    setuid_driver_entry.control         = NULL;
+    setuid_driver_entry.timeout         = NULL;
+    setuid_driver_entry.outputv         = NULL;
+    setuid_driver_entry.ready_async     = NULL;
+    setuid_driver_entry.flush           = NULL;
+    setuid_driver_entry.call            = NULL;
+    setuid_driver_entry.event           = NULL;
+    setuid_driver_entry.extended_marker = ERL_DRV_EXTENDED_MARKER;
+    setuid_driver_entry.major_version   = ERL_DRV_EXTENDED_MAJOR_VERSION;
+    setuid_driver_entry.minor_version   = ERL_DRV_EXTENDED_MINOR_VERSION;
+    setuid_driver_entry.driver_flags    = 0;
+    setuid_driver_entry.handle2         = NULL;
+    setuid_driver_entry.process_exit    = NULL;
+    setuid_driver_entry.stop_select     = NULL;
     return (ErlDrvEntry*) &setuid_driver_entry;
 }
 
