@@ -50,13 +50,13 @@
 %%%
 %%% This module translates JSON types into the following Erlang types:
 %%%
-%%%	JSON			Erlang
-%%%	----			------
-%%%	number			number
-%%%	string			string
-%%%	array			{array, ElementList}
-%%%	object			tagged proplist with string (or atom) keys (i.e. {struct, PropList} )
-%%%	true, false, null	atoms 'true', 'false', and 'null'
+%%%     JSON                    Erlang
+%%%     ----                    ------
+%%%     number                  number
+%%%     string                  string
+%%%     array                   {array, ElementList}
+%%%     object                  tagged proplist with string (or atom) keys (i.e. {struct, PropList} )
+%%%     true, false, null       atoms 'true', 'false', and 'null'
 %%%
 %%% Character Sets: the external representation, and the internal
 %%% representation of strings, are lists of UTF-16 code units.
@@ -125,9 +125,9 @@ encode(I) when is_integer(I) -> integer_to_list(I);
 encode(F) when is_float(F) -> float_to_list(F);
 encode(L) when is_list(L) ->
     case is_string(L) of
-	yes -> encode_string(L);
-	unicode -> encode_string(xmerl_ucs:to_utf8(L));
-	no -> encode({array, L})
+        yes -> encode_string(L);
+        unicode -> encode_string(xmerl_ucs:to_utf8(L));
+        no -> encode({array, L})
     end;
 encode({array, Props}) when is_list(Props) -> encode_array(Props);
 encode({struct, Props} = T) when is_list(Props) -> encode_object(T);
@@ -142,14 +142,14 @@ encode_string(S) -> encode_string(S, [$"]).
 encode_string([], Acc) -> lists:reverse([$" | Acc]);
 encode_string([C | Cs], Acc) ->
     case C of
-	$" -> encode_string(Cs, [$", $\\ | Acc]);
-	% (don't escape solidus on encode)
-	$\\ -> encode_string(Cs, [$\\, $\\ | Acc]);
-	$\b -> encode_string(Cs, [$b, $\\ | Acc]);	% note missing \
-	$\f -> encode_string(Cs, [$f, $\\ | Acc]);
-	$\n -> encode_string(Cs, [$n, $\\ | Acc]);
-	$\r -> encode_string(Cs, [$r, $\\ | Acc]);
-	$\t -> encode_string(Cs, [$t, $\\ | Acc]);
+        $" -> encode_string(Cs, [$", $\\ | Acc]);
+        % (don't escape solidus on encode)
+        $\\ -> encode_string(Cs, [$\\, $\\ | Acc]);
+        $\b -> encode_string(Cs, [$b, $\\ | Acc]);      % note missing \
+        $\f -> encode_string(Cs, [$f, $\\ | Acc]);
+        $\n -> encode_string(Cs, [$n, $\\ | Acc]);
+        $\r -> encode_string(Cs, [$r, $\\ | Acc]);
+        $\t -> encode_string(Cs, [$t, $\\ | Acc]);
         C when C >= 0, C < $\s ->
             % Control characters must be unicode-encoded.
             Hex = lists:flatten(io_lib:format("~4.16.0b", [C])),
@@ -165,7 +165,7 @@ encode_string([C | Cs], Acc) ->
 
 encode_object({struct, _Props} = Obj) ->
     M = obj_fold(fun({Key, Value}, Acc) ->
-	S = case Key of
+        S = case Key of
                 B when is_binary(B) -> encode_string(B);
                 L when is_list(L) ->
                     case is_string(L) of
@@ -176,11 +176,11 @@ encode_object({struct, _Props} = Obj) ->
                 A when is_atom(A) -> encode_string(atom_to_list(A));
                 _ -> exit({json_encode, {bad_key, Key}})
             end,
-	V = encode(Value),
-	case Acc of
-	    [] -> [S, $:, V];
-	    _ -> [Acc, $,, S, $:, V]
-	end
+        V = encode(Value),
+        case Acc of
+            [] -> [S, $:, V];
+            _ -> [Acc, $,, S, $:, V]
+        end
     end, [], Obj),
     [${, M, $}].
 
@@ -189,11 +189,11 @@ encode_object({struct, _Props} = Obj) ->
 
 encode_array(T) ->
     M = lists:foldl(fun(E, Acc) ->
-	V = encode(E),
-	case Acc of
-	    [] -> V;
-	    _ -> [Acc, $,, V]
-	end
+        V = encode(E),
+        case Acc of
+            [] -> V;
+            _ -> [Acc, $,, V]
+        end
     end, [], T),
     [$[, M, $]].
 
@@ -221,40 +221,40 @@ token([]) -> {more, []};
 token(eof) -> {done, eof, []};
 
 token("true" ++ Rest) -> {done, {ok, true}, Rest};
-token("tru")	-> {more, "tru"};
-token("tr")	-> {more, "tr"};
-token("t")	-> {more, "t"};
+token("tru")    -> {more, "tru"};
+token("tr")     -> {more, "tr"};
+token("t")      -> {more, "t"};
 
 token("false" ++ Rest) -> {done, {ok, false}, Rest};
-token("fals")	-> {more, "fals"};
-token("fal")	-> {more, "fal"};
-token("fa")	-> {more, "fa"};
-token("f")	-> {more, "f"};
+token("fals")   -> {more, "fals"};
+token("fal")    -> {more, "fal"};
+token("fa")     -> {more, "fa"};
+token("f")      -> {more, "f"};
 
 token("null" ++ Rest) -> {done, {ok, null}, Rest};
-token("nul")	-> {more, "nul"};
-token("nu")	-> {more, "nu"};
-token("n")	-> {more, "n"};
+token("nul")    -> {more, "nul"};
+token("nu")     -> {more, "nu"};
+token("n")      -> {more, "n"};
 
 token([C | Cs] = Input) ->
     case C of
-	$\s -> token(Cs);	% eat whitespace
-	$\t -> token(Cs);	% eat whitespace
-	$\n -> token(Cs);	% eat whitespace
-	$\r -> token(Cs);	% eat whitespace
-	$" -> scan_string(Input);
-	$- -> scan_number(Input);
-	D when D >= $0, D =< $9-> scan_number(Input);
-	${ -> {done, {ok, lcbrace}, Cs};
-	$} -> {done, {ok, rcbrace}, Cs};
-	$[ -> {done, {ok, lsbrace}, Cs};
-	$] -> {done, {ok, rsbrace}, Cs};
-	$: -> {done, {ok, colon}, Cs};
-	$, -> {done, {ok, comma}, Cs};
-	$/ -> case scan_comment(Cs) of
-	    {more, X} -> {more, X};
-	    {done, _, Chars} -> token(Chars)
-	end;
+        $\s -> token(Cs);       % eat whitespace
+        $\t -> token(Cs);       % eat whitespace
+        $\n -> token(Cs);       % eat whitespace
+        $\r -> token(Cs);       % eat whitespace
+        $" -> scan_string(Input);
+        $- -> scan_number(Input);
+        D when D >= $0, D =< $9-> scan_number(Input);
+        ${ -> {done, {ok, lcbrace}, Cs};
+        $} -> {done, {ok, rcbrace}, Cs};
+        $[ -> {done, {ok, lsbrace}, Cs};
+        $] -> {done, {ok, rsbrace}, Cs};
+        $: -> {done, {ok, colon}, Cs};
+        $, -> {done, {ok, comma}, Cs};
+        $/ -> case scan_comment(Cs) of
+            {more, X} -> {more, X};
+            {done, _, Chars} -> token(Chars)
+        end;
         _ -> {done, {error, {bad_char, C}}, Cs}
     end.
 
@@ -294,8 +294,8 @@ scan_number(eof) -> {done, {error, incomplete_number}, []};
 scan_number([$-, $- | _Ds]) -> {done, {error, invalid_number}, []};
 scan_number([$- | Ds] = Input) ->
     case scan_number(Ds) of
-	{more, _Cont} -> {more, Input};
-	{done, {ok, N}, CharList} -> {done, {ok, -1 * N}, CharList};
+        {more, _Cont} -> {more, Input};
+        {done, {ok, N}, CharList} -> {done, {ok, -1 * N}, CharList};
         {done, Other, Chars} -> {done, Other, Chars}
     end;
 scan_number([D | Ds] = Input) when D >= $0, D =< $9 ->
@@ -321,7 +321,8 @@ scan_fraction(Ds, I, X) -> scan_fraction(Ds, [], I, X).
 
 scan_fraction([], _Fs, _I, X) -> {more, X};
 scan_fraction(eof, Fs, I, _X) ->
-    R = list_to_float(lists:append([integer_to_list(I), ".", lists:reverse(Fs)])),
+    R = list_to_float(lists:append([integer_to_list(I), ".",
+                                    lists:reverse(Fs)])),
     {done, {ok, R}, eof};
 scan_fraction([D | Ds], Fs, I, X) when D >= $0, D =< $9 ->
     scan_fraction(Ds, [D | Fs], I, X);
@@ -329,7 +330,8 @@ scan_fraction([D | Ds], Fs, I, X) when D == $E; D == $e ->
     R = lists:append([integer_to_list(I), ".", lists:reverse(Fs)]),
     scan_exponent_begin(Ds, R, X);
 scan_fraction(Rest, Fs, I, _X) ->
-    R = list_to_float(lists:append([integer_to_list(I), ".", lists:reverse(Fs)])),
+    R = list_to_float(lists:append([integer_to_list(I), ".",
+                                    lists:reverse(Fs)])),
     {done, {ok, R}, Rest}.
 
 scan_exponent_begin(Ds, R, X) ->
@@ -426,16 +428,16 @@ first_continuation() ->
         (T, Cs) ->
             parse_value(T, Cs, fun(V, C2) ->
                 {done, {ok, V}, C2}
-	    end)
+            end)
     end}.
 
 %% Continuation Kt must accept (TokenOrEof, Chars)
 
 get_token(Chars, Kt) ->
     case token(Chars) of
-	{done, {ok, T}, Rest} -> Kt(T, Rest);
-	{done, eof, Rest} -> Kt(eof, Rest);
-	{done, {error, Reason}, Rest} -> {done, {error, Reason}, Rest};
+        {done, {ok, T}, Rest} -> Kt(T, Rest);
+        {done, eof, Rest} -> Kt(eof, Rest);
+        {done, {error, Reason}, Rest} -> {done, {error, Reason}, Rest};
         {more, X} -> {more, {X, Kt}}
     end.
 
@@ -455,11 +457,11 @@ parse_value(_, C, _Kv) -> {done, {error, syntax_error}, C}.
 
 parse_object(Chars, Kv) ->
     get_token(Chars, fun(T, C2) ->
-	Obj = obj_new(),
-	case T of
-	    rcbrace -> Kv(Obj, C2);		% empty object
-	    _ -> parse_object(Obj, T, C2, Kv)	% token must be string
-	end
+        Obj = obj_new(),
+        case T of
+            rcbrace -> Kv(Obj, C2);             % empty object
+            _ -> parse_object(Obj, T, C2, Kv)   % token must be string
+        end
     end).
 
 parse_object(_Obj, eof, C, _Kv) ->
@@ -481,13 +483,13 @@ parse_object2(Obj, S, C, Kv) ->
         (eof, C2) ->
             {done, {error, premature_eof}, C2};
         (T, C2) ->
-            parse_value(T, C2, fun(V, C3) ->	% V is member value
+            parse_value(T, C2, fun(V, C3) ->    % V is member value
                 Obj2 = obj_store(S, V, Obj),
                 get_token(C3, fun
                     (rcbrace, C4) ->    % "}" end of object
-						{struct, PropList1} = Obj2,
+                                                {struct, PropList1} = Obj2,
                         Kv({struct, lists:reverse(PropList1)}, C4);
-                    (comma, C4) ->		% "," another member follows
+                    (comma, C4) ->              % "," another member follows
                         get_token(C4, fun(T3, C5) ->
                             parse_object(Obj2, T3, C5, Kv)
                         end);
@@ -504,16 +506,16 @@ parse_object2(Obj, S, C, Kv) ->
 parse_array(C, Kv) ->
     get_token(C, fun
         (eof, C2) -> {done, {error, premature_eof}, C2};
-	(rsbrace, C2) -> Kv({array, []}, C2);  % empty array
+        (rsbrace, C2) -> Kv({array, []}, C2);  % empty array
         (T, C2) -> parse_array([], T, C2, Kv)
     end).
 
 parse_array(E, T, C, Kv) ->
     parse_value(T, C, fun(V, C2) ->
-	E2 = [V | E],
-	get_token(C2, fun
+        E2 = [V | E],
+        get_token(C2, fun
             (rsbrace, C3) ->        % "]" end of array
-	        Kv({array, lists:reverse(E2)}, C3);
+                Kv({array, lists:reverse(E2)}, C3);
 
             (comma, C3) ->          % "," another value follows
                 get_token(C3, fun(T3, C4) ->
@@ -577,7 +579,7 @@ obj_is_key(Key, {struct, Props}) ->
 %% Store a new member in an object.  Returns a new object.
 
 obj_store(KeyList, Value, {struct, Props}) when is_list(Props) ->
-	Key = try list_to_atom(KeyList)
+        Key = try list_to_atom(KeyList)
               catch error:badarg -> KeyList
               end,
     {struct, [{Key, Value} | proplists:delete(Key, Props)]}.
@@ -600,8 +602,10 @@ obj_fold(Fun, Acc, {struct, Props}) ->
 is_string([]) -> yes;
 is_string(List) -> is_string(List, non_unicode).
 
-is_string([C|Rest], non_unicode) when is_integer(C), C >= 0, C =< 255 -> is_string(Rest, non_unicode);
-is_string([C|Rest], _) when is_integer(C), C>= 0, C =< 65000 -> is_string(Rest, unicode);
+is_string([C|Rest], non_unicode) when is_integer(C), C >= 0, C =< 255 ->
+    is_string(Rest, non_unicode);
+is_string([C|Rest], _) when is_integer(C), C>= 0, C =< 65000 ->
+    is_string(Rest, unicode);
 is_string([], non_unicode) -> yes;
 is_string([], unicode) -> unicode;
 is_string(_, _) -> no.
@@ -621,8 +625,8 @@ is_string(_, _) -> no.
 test() ->
     E2Js = e2j_test_vec(),
     Failures = lists:foldl(fun({E, J}, Fs) ->
-	case (catch test_e2j(E, J)) of
-	    ok ->
+        case (catch test_e2j(E, J)) of
+            ok ->
                 case (catch round_trip(E)) of
                     ok ->
                         case (catch round_trip_one_char(E)) of
@@ -632,13 +636,13 @@ test() ->
                     Reason ->
                         [{round_trip, E, Reason} | Fs]
                 end;
-	    Reason ->
+            Reason ->
                 [{erlang_to_json, E, J, Reason} | Fs]
-	end;
+        end;
     (end_of_tests, Fs) -> Fs end, [], E2Js),
     case Failures of
-	[] -> ok;
-	_ -> {failed, Failures}
+        [] -> ok;
+        _ -> {failed, Failures}
     end.
 
 %% Test for conversion from Erlang to JSON.  Note that unequal strings
@@ -649,7 +653,7 @@ test() ->
 
 test_e2j(E, J) ->
     J2 = lists:flatten(encode(E)),
-    J = J2,					% raises error if unequal
+    J = J2,                                     % raises error if unequal
     ok.
 
 %% Test that Erlang -> JSON -> Erlang round-trip yields equivalent term.
@@ -657,7 +661,7 @@ test_e2j(E, J) ->
 round_trip(E) ->
     J2 = lists:flatten(encode(E)),
     {ok, E2} = decode_string(J2),
-    true = equiv(E, E2),			% raises error if false
+    true = equiv(E, E2),                        % raises error if false
     ok.
 
 %% Round-trip with one character at a time to test all continuations.
@@ -670,7 +674,7 @@ round_trip_one_char(E) ->
             {more, Cont} -> decode(Cont, [C])
         end
     end, {more, first_continuation()}, J ++ [eof]),
-    true = equiv(E, E2),			% raises error if false
+    true = equiv(E, E2),                        % raises error if false
     ok.
 
 %% Test for equivalence of Erlang terms.
@@ -682,8 +686,8 @@ equiv({struct, Props1}, {struct, Props2}) ->
     equiv_object(Props1, Props2);
 equiv(T1, T2) when is_tuple(T1), is_tuple(T2) ->
     equiv_tuple(T1, T2);
-equiv(N1, N2) when is_number(N1), is_number(N2)	-> N1 == N2;
-equiv(S1, S2) when is_list(S1), is_list(S2)	-> S1 == S2;
+equiv(N1, N2) when is_number(N1), is_number(N2) -> N1 == N2;
+equiv(S1, S2) when is_list(S1), is_list(S2)     -> S1 == S2;
 equiv(true, true) -> true;
 equiv(false, false) -> true;
 equiv(null, null) -> true.
@@ -696,7 +700,7 @@ equiv_object(Props1, Props2) ->
     L2 = lists:keysort(1, Props2),
     Pairs = lists:zip(L1, L2),
     true = lists:all(fun({{K1, V1}, {K2, V2}}) ->
-	equiv(K1, K2) and equiv(V1, V2)
+        equiv(K1, K2) and equiv(V1, V2)
     end, Pairs).
 
 %% Recursively compare tuple elements for equivalence.
@@ -706,7 +710,7 @@ equiv_tuple({}, {}) ->
 equiv_tuple(T1, T2) when size(T1) == size(T2) ->
     S = size(T1),
     lists:all(fun(I) ->
-	equiv(element(I, T1), element(I, T2))
+        equiv(element(I, T1), element(I, T2))
     end, lists:seq(1, S)).
 
 e2j_test_vec() -> [
