@@ -15,23 +15,23 @@
 -include_lib("kernel/include/file.hrl").
 -export([start/0, stop/0, hup/1, restart/0, modules/0, load/0]).
 -export([start_embedded/1, start_embedded/2, start_embedded/3, start_embedded/4,
-         add_server/2, create_gconf/2, create_sconf/2]).
+         add_server/2, create_gconf/2, create_sconf/2, setup_sconf/2]).
 
 -export([gconf_yaws_dir/1, gconf_trace/1, gconf_flags/1, gconf_logdir/1,
-         gconf_ebin_dir/1, gconf_runmods/1, gconf_keepalive_timeout/1,
-         gconf_keepalive_maxuses/1, gconf_max_num_cached_files/1,
-         gconf_max_num_cached_bytes/1, gconf_max_size_cached_file/1,
-         gconf_max_connections/1, gconf_process_options/1,
-         gconf_large_file_chunk_size/1, gconf_mnesia_dir/1,
-         gconf_log_wrap_size/1, gconf_cache_refresh_secs/1, gconf_include_dir/1,
-         gconf_phpexe/1, gconf_yaws/1, gconf_id/1, gconf_enable_soap/1,
-         gconf_soap_srv_mods/1, gconf_ysession_mod/1,
+         gconf_ebin_dir/1, gconf_src_dir/1, gconf_runmods/1,
+         gconf_keepalive_timeout/1, gconf_keepalive_maxuses/1,
+         gconf_max_num_cached_files/1, gconf_max_num_cached_bytes/1,
+         gconf_max_size_cached_file/1, gconf_max_connections/1,
+         gconf_process_options/1, gconf_large_file_chunk_size/1,
+         gconf_mnesia_dir/1, gconf_log_wrap_size/1, gconf_cache_refresh_secs/1,
+         gconf_include_dir/1, gconf_phpexe/1, gconf_yaws/1, gconf_id/1,
+         gconf_enable_soap/1, gconf_soap_srv_mods/1, gconf_ysession_mod/1,
          gconf_acceptor_pool_size/1, gconf_mime_types_info/1]).
 
 -export([sconf_port/1, sconf_flags/1, sconf_redirect_map/1, sconf_rhost/1,
          sconf_rmethod/1, sconf_docroot/1, sconf_xtra_docroots/1,
-         sconf_listen/1, sconf_servername/1, sconf_yaws/1, sconf_ets/1,
-         sconf_ssl/1, sconf_authdirs/1, sconf_patial_post_size/1,
+         sconf_listen/1, sconf_servername/1, sconf_serveralias/1, sconf_yaws/1,
+         sconf_ets/1, sconf_ssl/1, sconf_authdirs/1, sconf_partial_post_size/1,
          sconf_appmods/1, sconf_expires/1, sconf_errormod_401/1,
          sconf_errormod_404/1, sconf_arg_rewrite_mode/1, sconf_logger_mod/1,
          sconf_opaque/1, sconf_start_mod/1, sconf_allowed_scripts/1,
@@ -216,6 +216,7 @@ gconf_trace                (#gconf{trace                 = X}) -> X.
 gconf_flags                (#gconf{flags                 = X}) -> X.
 gconf_logdir               (#gconf{logdir                = X}) -> X.
 gconf_ebin_dir             (#gconf{ebin_dir              = X}) -> X.
+gconf_src_dir              (#gconf{src_dir               = X}) -> X.
 gconf_runmods              (#gconf{runmods               = X}) -> X.
 gconf_keepalive_timeout    (#gconf{keepalive_timeout     = X}) -> X.
 gconf_keepalive_maxuses    (#gconf{keepalive_maxuses     = X}) -> X.
@@ -248,11 +249,12 @@ sconf_docroot              (#sconf{docroot               = X}) -> X.
 sconf_xtra_docroots        (#sconf{xtra_docroots         = X}) -> X.
 sconf_listen               (#sconf{listen                = X}) -> X.
 sconf_servername           (#sconf{servername            = X}) -> X.
+sconf_serveralias          (#sconf{serveralias           = X}) -> X.
 sconf_yaws                 (#sconf{yaws                  = X}) -> X.
 sconf_ets                  (#sconf{ets                   = X}) -> X.
 sconf_ssl                  (#sconf{ssl                   = X}) -> X.
 sconf_authdirs             (#sconf{authdirs              = X}) -> X.
-sconf_patial_post_size     (#sconf{partial_post_size     = X}) -> X.
+sconf_partial_post_size    (#sconf{partial_post_size     = X}) -> X.
 sconf_appmods              (#sconf{appmods               = X}) -> X.
 sconf_expires              (#sconf{expires               = X}) -> X.
 sconf_errormod_401         (#sconf{errormod_401          = X}) -> X.
@@ -451,16 +453,19 @@ setup_mime_types_info(SL, DefaultMTI) ->
             M;
         MProps when is_list(MProps) ->
             M = #mime_types_info{},
-            #mime_types_info{mime_types_file = lkup(mime_types_file, MProps,
-                                                    M#mime_types_info.mime_types_file),
+            #mime_types_info{mime_types_file =
+                                 lkup(mime_types_file, MProps,
+                                      M#mime_types_info.mime_types_file),
                              types           = lkup(types, MProps,
                                                     M#mime_types_info.types),
                              charsets        = lkup(charsets, MProps,
                                                     M#mime_types_info.charsets),
-                             default_type    = lkup(default_type, MProps,
-                                                    M#mime_types_info.default_type),
-                             default_charset = lkup(default_charset, MProps,
-                                                    M#mime_types_info.default_charset)}
+                             default_type    =
+                                 lkup(default_type, MProps,
+                                      M#mime_types_info.default_type),
+                             default_charset =
+                                 lkup(default_charset, MProps,
+                                      M#mime_types_info.default_charset)}
     end.
 
 
@@ -473,6 +478,7 @@ setup_gconf(GL, GC) ->
                                                 GC#gconf.flags),
            logdir                = lkup(logdir, GL, GC#gconf.logdir),
            ebin_dir              = lkup(ebin_dir, GL, GC#gconf.ebin_dir),
+           src_dir               = lkup(src_dir, GL, GC#gconf.src_dir),
            runmods               = lkup(runmods, GL, GC#gconf.runmods),
            keepalive_timeout     = lkup(keepalive_timeout, GL,
                                         GC#gconf.keepalive_timeout),
@@ -529,6 +535,10 @@ set_gc_flags([{pick_first_virthost_on_nomatch, Bool}|T], Flags) ->
     set_gc_flags(T, flag(Flags, ?GC_PICK_FIRST_VIRTHOST_ON_NOMATCH,Bool));
 set_gc_flags([{use_old_ssl, Bool}|T], Flags) ->
     set_gc_flags(T, flag(Flags,?GC_USE_OLD_SSL,Bool));
+set_gc_flags([{use_erlang_sendfile, Bool}|T], Flags) ->
+    set_gc_flags(T, flag(Flags,?GC_USE_ERLANG_SENDFILE,Bool));
+set_gc_flags([{use_yaws_sendfile, Bool}|T], Flags) ->
+    set_gc_flags(T, flag(Flags,?GC_USE_YAWS_SENDFILE,Bool));
 set_gc_flags([_|T], Flags) ->
     set_gc_flags(T, Flags);
 set_gc_flags([], Flags) ->
@@ -540,7 +550,8 @@ setup_sconf(SL, SC) ->
     #sconf{port                  = lkup(port, SL, SC#sconf.port),
            flags                 = set_sc_flags(lkup(flags, SL, []),
                                                 SC#sconf.flags),
-           redirect_map          = lkup(redirect_map, SL, SC#sconf.redirect_map),
+           redirect_map          = lkup(redirect_map, SL,
+                                        SC#sconf.redirect_map),
            rhost                 = lkup(rhost, SL, SC#sconf.rhost),
            rmethod               = lkup(rmethod, SL, SC#sconf.rmethod),
            docroot               = lkup(docroot, SL, SC#sconf.docroot),
@@ -548,6 +559,7 @@ setup_sconf(SL, SC) ->
                                         SC#sconf.xtra_docroots),
            listen                = lkup(listen, SL, SC#sconf.listen),
            servername            = lkup(servername, SL, SC#sconf.servername),
+           serveralias           = lkup(serveralias, SL, SC#sconf.serveralias),
            yaws                  = lkup(yaws, SL, SC#sconf.yaws),
            ets                   = lkup(ets, SL, SC#sconf.ets),
            ssl                   = setup_ssl(SL, SC#sconf.ssl),
@@ -556,8 +568,10 @@ setup_sconf(SL, SC) ->
                                         SC#sconf.partial_post_size),
            appmods               = lkup(appmods, SL, SC#sconf.appmods),
            expires               = lkup(expires, SL, SC#sconf.expires),
-           errormod_401          = lkup(errormod_401, SL, SC#sconf.errormod_401),
-           errormod_404          = lkup(errormod_404, SL, SC#sconf.errormod_404),
+           errormod_401          = lkup(errormod_401, SL,
+                                        SC#sconf.errormod_401),
+           errormod_404          = lkup(errormod_404, SL,
+                                        SC#sconf.errormod_404),
            errormod_crash        = lkup(errormod_crash, SL,
                                         SC#sconf.errormod_crash),
            arg_rewrite_mod       = lkup(arg_rewrite_mod, SL,
@@ -1267,6 +1281,7 @@ outh_set_static_headers(Req, UT, Headers, Range) ->
            encoding          = Encoding,
            date              = make_date_header(),
            server            = make_server_header(),
+           last_modified     = make_last_modified_header(UT#urltype.finfo),
            etag              = make_etag_header(UT#urltype.finfo),
            content_range     = make_content_range_header(Range),
            content_length    = make_content_length_header(Length),
@@ -1290,6 +1305,7 @@ outh_set_304_headers(Req, UT, Headers) ->
            chunked        = false,
            date           = make_date_header(),
            server         = make_server_header(),
+           last_modified  = make_last_modified_header(UT#urltype.finfo),
            etag           = make_etag_header(UT#urltype.finfo),
            content_length = make_content_length_header(0),
            connection     = make_connection_close_header(DoClose),
@@ -1424,14 +1440,7 @@ make_allow_header() ->
 make_allow_header(Options) ->
     case Options of
         [] ->
-            HasDav = ?sc_has_dav(get(sc)),
-            ["Allow: GET, POST, OPTIONS, HEAD",
-             case HasDav of
-                 true ->
-                     ", PUT, DELETE, PROPFIND, PROPPATCH, MKCOL, MOVE, COPY";
-                 false ->
-                     ""
-             end, "\r\n"];
+            ["Allow: GET, POST, OPTIONS, HEAD\r\n"];
         _ ->
             ["Allow: ",
              lists:foldl(fun(M, "") -> atom_to_list(M);
@@ -1441,14 +1450,11 @@ make_allow_header(Options) ->
     end.
 make_server_header() ->
     Sc = get(sc),
-    HasDav = ?sc_has_dav(Sc),
     Signature = case Sc#sconf.yaws of
                     undefined -> (get(gc))#gconf.yaws;
                     S         -> S
                 end,
-    ["Server: ", Signature, "\r\n" | if HasDav == true -> ["DAV: 1, 2, 3\r\n"];
-                                        true           -> []
-                                     end].
+    ["Server: ", Signature, "\r\n"].
 
 make_last_modified_header(FI) ->
     Then = FI#file_info.mtime,
@@ -1634,17 +1640,11 @@ outh_serialize() ->
                      undefined -> make_content_encoding_header(H#outh.encoding);
                      CE        -> CE
                  end,
-    {LastModified, Expires, CacheControl} =
+    {Expires, CacheControl} =
         case erase(file_info) of
             undefined ->
-                {H#outh.last_modified, H#outh.expires, H#outh.cache_control};
+                {H#outh.expires, H#outh.cache_control};
             FI ->
-                LM = case H#outh.last_modified of
-                         undefined ->
-                             make_last_modified_header(FI);
-                         _ ->
-                             H#outh.last_modified
-                     end,
                 {E, CC} = case {H#outh.expires, H#outh.cache_control} of
                               {undefined, undefined} ->
                                   CT = outh_get_content_type(),
@@ -1652,7 +1652,7 @@ outh_serialize() ->
                               _ ->
                                   {H#outh.expires, H#outh.cache_control}
                           end,
-                {LM, E, CC}
+                {E, CC}
         end,
 
     %% Add 'Accept-Encoding' in the 'Vary:' header if the compression is enabled
@@ -1661,7 +1661,8 @@ outh_serialize() ->
     SC=get(sc),
     Vary = case (?sc_has_deflate(SC) orelse H#outh.encoding == deflate) of
                true when H#outh.contlen /= undefined, H#outh.contlen /= 0;
-                         H#outh.act_contlen /= undefined, H#outh.act_contlen /= 0 ->
+                         H#outh.act_contlen /= undefined,
+                         H#outh.act_contlen /= 0 ->
                    Fields = outh_get_vary_fields(),
                    Fun    = fun("*") -> true;
                                (F)   -> (to_lower(F) == "accept-encoding")
@@ -1679,7 +1680,7 @@ outh_serialize() ->
                noundef(H#outh.location),
                noundef(H#outh.date),
                noundef(H#outh.allow),
-               noundef(LastModified),
+               noundef(H#outh.last_modified),
                noundef(Expires),
                noundef(CacheControl),
                noundef(H#outh.etag),
@@ -2177,8 +2178,15 @@ http_collect_headers(CliSock, Req, H, SSL, Count) when Count < 1000 ->
                                  H#headers{authorization = parse_auth(X)},
                                  SSL, Count+1);
         {ok, {http_header, _Num, 'X-Forwarded-For', _, X}} ->
-            http_collect_headers(CliSock, Req, H#headers{x_forwarded_for=X},
-                                 SSL, Count+1);
+            case H#headers.x_forwarded_for of
+                undefined ->
+                    http_collect_headers(CliSock, Req, H#headers{x_forwarded_for=X},
+                                         SSL, Count+1);
+                PrevXF ->
+                    NewXF = join_sep([PrevXF,X], ", "),
+                    http_collect_headers(CliSock, Req, H#headers{x_forwarded_for=NewXF},
+                                         SSL, Count+1)
+            end;
         {ok, http_eoh} ->
             H;
 
