@@ -271,19 +271,20 @@ vsn(IP) when size(IP) =:= 8 ->
     "(ipv6)".
 
 -define(IPV4_FMT, "~p.~p.~p.~p").
--define(IPV6_FMT, "~2.16.0b~2.16.0b:~2.16.0b~2.16.0b:~2.16.0b~2.16.0b:~2.16.0b~2.16.0b").
+-define(IPV6_FMT,
+        "~2.16.0b~2.16.0b:~2.16.0b~2.16.0b:~2.16.0b~2.16.0b:~2.16.0b~2.16.0b").
 
 format_ip(IP) ->
     case size(IP) of
-	4 ->
-	    {A, B, C, D} = IP,
-	    io_lib:format(?IPV4_FMT,
-			  [A, B, C, D]);
+        4 ->
+            {A, B, C, D} = IP,
+            io_lib:format(?IPV4_FMT,
+                          [A, B, C, D]);
 
-	8 ->
-	    {A, B, C, D, E, F, G, H} = IP,
-	    io_lib:format(?IPV6_FMT,
-			  [A, B, C, D, E, F, G, H])
+        8 ->
+            {A, B, C, D, E, F, G, H} = IP,
+            io_lib:format(?IPV6_FMT,
+                          [A, B, C, D, E, F, G, H])
     end.
 
 
@@ -312,22 +313,22 @@ a_stats() ->
     Servers2 = parse(Servers1),
 
     case Servers2 of
-	[] ->
-	    f("No statistics available~n", []);
+        [] ->
+            f("No statistics available~n", []);
 
-	Servers2 ->
-	    Stats = fstats(Servers2),
-	    Header = f("Host IP Port Hits Sent~n", []),
+        Servers2 ->
+            Stats = fstats(Servers2),
+            Header = f("Host IP Port Hits Sent~n", []),
 
-	    Lines = lists:map(fun({Host, IP0, Port, {Hits, Sent}}) ->
-				      %% we don't use inet_parse:ntoa/1
-				      %% since it's not documented
-				      IP = format_ip(IP0),
-				      IPVsn = vsn(IP0),
-				      f("~s~s ~s ~p ~p ~p~n",
-					[Host, IPVsn, IP, Port, Hits, Sent])
-			      end, Stats),
-	    [Header, Lines]
+            Lines = lists:map(fun({Host, IP0, Port, {Hits, Sent}}) ->
+                                      %% we don't use inet_parse:ntoa/1
+                                      %% since it's not documented
+                                      IP = format_ip(IP0),
+                                      IPVsn = vsn(IP0),
+                                      f("~s~s ~s ~p ~p ~p~n",
+                                        [Host, IPVsn, IP, Port, Hits, Sent])
+                              end, Stats),
+            [Header, Lines]
     end.
 
 parse(V) ->
@@ -336,7 +337,8 @@ parse([], Acc) ->
     Acc;
 parse([#sconf{stats=undefined}|Tail], Acc) ->
     parse(Tail, Acc);
-parse([#sconf{listen=IP, port=Port, servername=Servername, stats=Stats}|Tail], Acc) ->
+parse([#sconf{listen=IP, port=Port, servername=Servername,
+              stats=Stats}|Tail], Acc) ->
     Host = {Servername, IP, Port, Stats},
     parse(Tail, [Host|Acc]).
 
