@@ -13,6 +13,7 @@
 
 -include("../include/yaws.hrl").
 -include("../include/yaws_api.hrl").
+-include("yaws_configure.hrl").
 
 -include_lib("kernel/include/file.hrl").
 
@@ -1133,7 +1134,8 @@ frag_state_machine(State, #ws_frame_info{opcode = Op}) ->
             State;
         true ->
             %% Everything else is wrong
-            {fail_connection, ?WS_STATUS_PROTO_ERROR, <<"fragmentation rules violated">>}
+            {fail_connection, ?WS_STATUS_PROTO_ERROR,
+             <<"fragmentation rules violated">>}
     end.
 
 
@@ -1245,7 +1247,13 @@ query_header(HeaderName, Headers) ->
 query_header(Header, Headers, Default) ->
     yaws_api:get_header(Headers, Header, Default).
 
+-ifdef(HAVE_CRYPTO_HASH).
+-define(CRYPTO_HASH(V), crypto:hash(sha,V)).
+-else.
+-define(CRYPTO_HASH(V), crypto:sha(V)).
+-endif.
+
 hash_nonce(Nonce) ->
     Salted = Nonce ++ "258EAFA5-E914-47DA-95CA-C5AB0DC85B11",
-    HashBin = crypto:sha(Salted),
+    HashBin = ?CRYPTO_HASH(Salted),
     base64:encode_to_string(HashBin).
