@@ -39,6 +39,8 @@ start() ->
     test_embedded_id_dir(),
     test_chained_appmods(),
     test_cache_appmod(),
+    test_multi_forwarded_for(),
+    test_log_rotation(),
     ibrowse:stop().
 
 
@@ -829,6 +831,7 @@ test_sslaccept_timeout() ->
 test_ssl_multipart_post() ->
     io:format("ssl_multipart_post_test\n", []),
     ok = application:start(crypto),
+    ok = application:start(asn1),
     ok = application:start(public_key),
     ok = application:start(ssl),
     Boundary = "----------------------------3e9876546ecf\r\n",
@@ -844,6 +847,7 @@ test_ssl_multipart_post() ->
     ?line {ok, "200", _, _} = ibrowse:send_req(Uri, Headers, post, Data, Options),
     ok = application:stop(ssl),
     ok = application:stop(public_key),
+    ok = application:stop(asn1),
     ok = application:stop(crypto),
     ok.
 
@@ -941,6 +945,56 @@ test_cache_appmod() ->
 
     ok.
 
+test_multi_forwarded_for() ->
+    io:format("test_multi_forwarded_for\n", []),
+    %% apparently ibrowse can't handle sending two separate headers with
+    %% the same name but different values, which is needed for this test
+    ?line {ok, S} = gen_tcp:connect(localhost, 8014, [{active,false},
+                                                      {packet,http}]),
+    ok = gen_tcp:send(S, ["GET / HTTP/1.1\r\nHost: localhost\r\n"
+                          "X-Forwarded-For: 192.168.1.1\r\n",
+                          "X-Forwarded-For: 192.168.1.2\r\n\r\n"]),
+    ?line ok = check_forwarded_for(S),
+    ok.
+
+check_forwarded_for(S) ->
+    inet:setopts(S, [{active,once}]),
+    receive
+        {http, S, {http_response, _, Code, _}} ->
+            gen_tcp:close(S),
+            case Code of
+                200 ->
+                    ok;
+                _ ->
+                    Code
+            end
+    end.
+
+test_log_rotation() ->
+    io:format("test_log_rotation\n", []),
+    %% Write 1M of data in .access and .auth log to check the log rotation
+    ?line {ok, Fd1} = file:open("./logs/localhost:8000.access", [write]),
+    ?line ok = file:write(Fd1, lists:duplicate(1000001, $a)),
+    file:close(Fd1),
+    file:sync(Fd1),
+
+    ?line {ok, Fd2} = file:open("./logs/localhost:8000.auth", [write]),
+    ?line ok = file:write(Fd2, lists:duplicate(1000001, $a)),
+    file:close(Fd2),
+    file:sync(Fd2),
+
+    ?line {ok, "200", _, _} =
+        ibrowse:send_req("http://localhost:8000/wrap_log", [], get),
+
+    timer:sleep(500),
+
+    ?line {ok, _} = file:read_file_info("./logs/localhost:8000.access.old"),
+    ?line {ok, _} = file:read_file_info("./logs/localhost:8000.auth.old"),
+    ?line {ok, _} = file:read_file_info("./logs/localhost:8000.access"),
+    ?line {ok, _} = file:read_file_info("./logs/localhost:8000.auth"),
+
+    ok.
+
 %% used for appmod tests
 %%
 out(_A) ->
